@@ -34,9 +34,9 @@
 
 #include "ephy-debug.h"
 #include "ephy-gui.h"
+#include "ephy-stock-icons.h"
 
-#include "AutoJSContextStack.h"
-#include "AutoWindowModalState.h"
+#include "AutoModalDialog.h"
 #include "EphyUtils.h"
 
 #include "GeckoCookiePromptService.h"
@@ -71,22 +71,20 @@ GeckoCookiePromptService::CookieDialog (nsIDOMWindow *aParent,
   // TODO short-circuit and accept session cookies as per preference
   // TODO until mozilla starts supporting it natively?
 
-  GtkWidget *parent = EphyUtils::FindGtkParent (aParent);
-  NS_ENSURE_TRUE(parent, NS_ERROR_INVALID_POINTER);
-
-  nsresult rv;
-  AutoJSContextStack stack;
-  rv = stack.Init ();
-  if (NS_FAILED (rv)) {
-    return rv;
+  AutoModalDialog modalDialog (aParent, PR_FALSE);
+  if (!modalDialog.ShouldShow ()) {
+    *_retval = PR_FALSE;
+    *_checkValue = PR_FALSE;
+    return NS_OK;
   }
 
-  AutoWindowModalState modalState (aParent);
+  GtkWindow *parent = modalDialog.GetParent ();
+  NS_ENSURE_TRUE(parent, NS_ERROR_INVALID_POINTER);
 
   nsCString host(aHostname);
 
   GtkWidget *dialog = gtk_message_dialog_new
-                        (GTK_WINDOW (parent),
+                        (parent,
                          GTK_DIALOG_MODAL /* FIXME mozilla sucks! */,
                          GTK_MESSAGE_QUESTION,
                          GTK_BUTTONS_NONE,
@@ -96,7 +94,7 @@ GeckoCookiePromptService::CookieDialog (nsIDOMWindow *aParent,
   GtkDialog *gdialog = GTK_DIALOG (dialog);
   GtkMessageDialog *message_dialog = GTK_MESSAGE_DIALOG (dialog);
 
-  gtk_window_set_icon_name (window, "web-browser");
+  gtk_window_set_icon_name (window, EPHY_STOCK_EPHY);
   gtk_window_set_title (window, _("Accept Cookie?"));
 
   if (aChangingCookie) {
@@ -140,7 +138,7 @@ GeckoCookiePromptService::CookieDialog (nsIDOMWindow *aParent,
                          _("_Accept"), GTK_RESPONSE_ACCEPT);
   gtk_dialog_set_default_response (gdialog, GTK_RESPONSE_ACCEPT);
 
-  int response = gtk_dialog_run (gdialog);
+  int response = modalDialog.Run (gdialog);
 
   if (response == GTK_RESPONSE_ACCEPT || response == GTK_RESPONSE_REJECT) {
     *_retval = (response == GTK_RESPONSE_ACCEPT);
