@@ -14,13 +14,14 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id: ephy-bookmarks-ui.c,v 1.15 2006/09/13 11:34:24 chpe Exp $
+ *  $Id$
  */
 
 #include "config.h"
 
+#include "eel-gconf-extensions.h"
 #include "ephy-bookmarks.h"
 #include "ephy-bookmarks-ui.h"
 #include "ephy-bookmarks-menu.h"
@@ -43,11 +44,12 @@
 #include "ephy-file-helpers.h"
 #include "ephy-gui.h"
 #include "ephy-stock-icons.h"
+#include "ephy-prefs.h"
 #include "egg-editable-toolbar.h"
 
 #include <string.h>
 #include <glib/gi18n.h>
-#include <gtk/gtkmain.h>
+#include <gtk/gtk.h>
 
 #define BM_WINDOW_DATA_KEY "bookmarks-window-data"
 
@@ -432,6 +434,8 @@ ephy_bookmarks_ui_add_bookmark (GtkWindow *parent,
 	EphyBookmarks *bookmarks;
 	EphyNode *bookmark;
 	GtkWidget *dialog;
+
+	if (eel_gconf_get_boolean (CONF_LOCKDOWN_DISABLE_BOOKMARK_EDITING)) return;
 	
 	bookmarks = ephy_shell_get_bookmarks (ephy_shell_get_default ());
 	bookmark = ephy_bookmarks_add (bookmarks, title, location);
